pub struct Image {Show 17 fields
pub aliases: Option<Vec<ImageAlias>>,
pub architecture: Option<String>,
pub auto_update: Option<bool>,
pub cached: Option<bool>,
pub created_at: Option<DateTime<FixedOffset>>,
pub expires_at: Option<DateTime<FixedOffset>>,
pub filename: Option<String>,
pub fingerprint: Option<String>,
pub last_used_at: Option<DateTime<FixedOffset>>,
pub profiles: Option<Vec<String>>,
pub project: Option<String>,
pub properties: Option<HashMap<String, String>>,
pub public: Option<bool>,
pub size: Option<i64>,
pub type: Option<String>,
pub update_source: Option<Box<ImageSource>>,
pub uploaded_at: Option<DateTime<FixedOffset>>,
}Expand description
Image : Image represents an image
Fields
aliases: Option<Vec<ImageAlias>>List of aliases
architecture: Option<String>Architecture
auto_update: Option<bool>Whether the image should auto-update when a new build is available
cached: Option<bool>Whether the image is an automatically cached remote image
created_at: Option<DateTime<FixedOffset>>When the image was originally created
expires_at: Option<DateTime<FixedOffset>>When the image becomes obsolete
filename: Option<String>Original filename
fingerprint: Option<String>Full SHA-256 fingerprint
last_used_at: Option<DateTime<FixedOffset>>Last time the image was used
profiles: Option<Vec<String>>List of profiles to use when creating from this image (if none provided by user)
project: Option<String>Project name
properties: Option<HashMap<String, String>>Descriptive properties
public: Option<bool>Whether the image is available to unauthenticated users
size: Option<i64>Size of the image in bytes
type: Option<String>Type of image (container or virtual-machine)
update_source: Option<Box<ImageSource>>uploaded_at: Option<DateTime<FixedOffset>>When the image was added to this server
Implementations