pub struct ImageAlias {
pub description: Option<String>,
pub name: Option<String>,
}Expand description
ImageAlias : ImageAlias represents an alias from the alias list of an image
Fields
description: Option<String>Description of the alias
name: Option<String>Name of the alias
Implementations
Sourceimpl ImageAlias
impl ImageAlias
Sourcepub fn new() -> ImageAlias
pub fn new() -> ImageAlias
ImageAlias represents an alias from the alias list of an image