pub struct ImageMetadataTemplate {
pub create_only: Option<bool>,
pub gid: Option<String>,
pub mode: Option<String>,
pub properties: Option<HashMap<String, String>>,
pub template: Option<String>,
pub uid: Option<String>,
pub when: Option<Vec<String>>,
}Expand description
ImageMetadataTemplate : ImageMetadataTemplate represents a template entry in image metadata (used in image tarball)
Fields
create_only: Option<bool>Whether to trigger only if the file is missing
gid: Option<String>The file owner gid.
mode: Option<String>The file permissions.
properties: Option<HashMap<String, String>>Key/value properties to pass to the template
template: Option<String>The template itself as a valid pongo2 template
uid: Option<String>The file owner uid.
when: Option<Vec<String>>When to trigger the template (create, copy or start)
Implementations
Sourceimpl ImageMetadataTemplate
impl ImageMetadataTemplate
Sourcepub fn new() -> ImageMetadataTemplate
pub fn new() -> ImageMetadataTemplate
ImageMetadataTemplate represents a template entry in image metadata (used in image tarball)