pub struct InstanceExecPost {
pub command: Option<Vec<String>>,
pub cwd: Option<String>,
pub environment: Option<HashMap<String, String>>,
pub group: Option<i32>,
pub height: Option<i64>,
pub interactive: Option<bool>,
pub record_output: Option<bool>,
pub user: Option<i32>,
pub wait_for_websocket: Option<bool>,
pub width: Option<i64>,
}Fields
command: Option<Vec<String>>Command and its arguments
cwd: Option<String>Current working directory for the command
environment: Option<HashMap<String, String>>Additional environment to pass to the command
group: Option<i32>GID of the user to spawn the command as
height: Option<i64>Terminal height in rows (for interactive)
interactive: Option<bool>Whether the command is to be spawned in interactive mode (singled PTY instead of 3 PIPEs)
record_output: Option<bool>Whether to capture the output for later download (requires non-interactive)
user: Option<i32>UID of the user to spawn the command as
wait_for_websocket: Option<bool>Whether to wait for all websockets to be connected before spawning the command
width: Option<i64>Terminal width in characters (for interactive)
Implementations
Sourceimpl InstanceExecPost
impl InstanceExecPost
pub fn new() -> InstanceExecPost