pub struct InstanceFull {Show 22 fields
pub architecture: Option<String>,
pub backups: Option<Vec<InstanceBackup>>,
pub config: Option<Value>,
pub created_at: Option<DateTime<FixedOffset>>,
pub description: Option<String>,
pub devices: Option<Value>,
pub disk_only: Option<bool>,
pub ephemeral: Option<bool>,
pub expanded_config: Option<Value>,
pub expanded_devices: Option<Value>,
pub last_used_at: Option<DateTime<FixedOffset>>,
pub location: Option<String>,
pub name: Option<String>,
pub profiles: Option<Vec<String>>,
pub project: Option<String>,
pub restore: Option<String>,
pub snapshots: Option<Vec<InstanceSnapshot>>,
pub state: Option<Box<InstanceState>>,
pub stateful: Option<bool>,
pub status: Option<String>,
pub status_code: Option<i64>,
pub type: Option<String>,
}Fields
architecture: Option<String>Architecture name
backups: Option<Vec<InstanceBackup>>List of backups.
config: Option<Value>Instance configuration (see doc/instances.md)
created_at: Option<DateTime<FixedOffset>>Instance creation timestamp
description: Option<String>Instance description
devices: Option<Value>Instance devices (see doc/instances.md)
disk_only: Option<bool>Whether only the instances disk should be restored
ephemeral: Option<bool>Whether the instance is ephemeral (deleted on shutdown)
expanded_config: Option<Value>Expanded configuration (all profiles and local config merged)
expanded_devices: Option<Value>Expanded devices (all profiles and local devices merged)
last_used_at: Option<DateTime<FixedOffset>>Last start timestamp
location: Option<String>What cluster member this instance is located on
name: Option<String>Instance name
profiles: Option<Vec<String>>List of profiles applied to the instance
project: Option<String>Instance project name
restore: Option<String>If set, instance will be restored to the provided snapshot name
snapshots: Option<Vec<InstanceSnapshot>>List of snapshots.
state: Option<Box<InstanceState>>stateful: Option<bool>Whether the instance currently has saved state on disk
status: Option<String>Instance status (see instance_state)
status_code: Option<i64>type: Option<String>The type of instance (container or virtual-machine)
Implementations
Sourceimpl InstanceFull
impl InstanceFull
pub fn new() -> InstanceFull