pub struct InstancePut {
pub architecture: Option<String>,
pub config: Option<Value>,
pub description: Option<String>,
pub devices: Option<Value>,
pub disk_only: Option<bool>,
pub ephemeral: Option<bool>,
pub profiles: Option<Vec<String>>,
pub restore: Option<String>,
pub stateful: Option<bool>,
}Fields
architecture: Option<String>Architecture name
config: Option<Value>Instance configuration (see doc/instances.md)
description: Option<String>Instance description
devices: Option<Value>Instance devices (see doc/instances.md)
disk_only: Option<bool>Whether only the instances disk should be restored
ephemeral: Option<bool>Whether the instance is ephemeral (deleted on shutdown)
profiles: Option<Vec<String>>List of profiles applied to the instance
restore: Option<String>If set, instance will be restored to the provided snapshot name
stateful: Option<bool>Whether the instance currently has saved state on disk
Implementations
Sourceimpl InstancePut
impl InstancePut
pub fn new() -> InstancePut