pub struct InstanceStateNetworkAddress {
pub address: Option<String>,
pub family: Option<String>,
pub netmask: Option<String>,
pub scope: Option<String>,
}Expand description
InstanceStateNetworkAddress : InstanceStateNetworkAddress represents a network address as part of the network section of an instance’s state.
Fields
address: Option<String>IP address
family: Option<String>Network family (inet or inet6)
netmask: Option<String>Network mask
scope: Option<String>Address scope (local, link or global)
Implementations
Sourceimpl InstanceStateNetworkAddress
impl InstanceStateNetworkAddress
Sourcepub fn new() -> InstanceStateNetworkAddress
pub fn new() -> InstanceStateNetworkAddress
InstanceStateNetworkAddress represents a network address as part of the network section of an instance’s state.