pub struct InstanceStateNetworkCounters {
pub bytes_received: Option<i64>,
pub bytes_sent: Option<i64>,
pub errors_received: Option<i64>,
pub errors_sent: Option<i64>,
pub packets_dropped_inbound: Option<i64>,
pub packets_dropped_outbound: Option<i64>,
pub packets_received: Option<i64>,
pub packets_sent: Option<i64>,
}Expand description
InstanceStateNetworkCounters : InstanceStateNetworkCounters represents packet counters as part of the network section of an instance’s state.
Fields
bytes_received: Option<i64>Number of bytes received
bytes_sent: Option<i64>Number of bytes sent
errors_received: Option<i64>Number of errors received
errors_sent: Option<i64>Number of errors sent
packets_dropped_inbound: Option<i64>Number of inbound packets dropped
packets_dropped_outbound: Option<i64>Number of outbound packets dropped
packets_received: Option<i64>Number of packets received
packets_sent: Option<i64>Number of packets sent
Implementations
Sourceimpl InstanceStateNetworkCounters
impl InstanceStateNetworkCounters
Sourcepub fn new() -> InstanceStateNetworkCounters
pub fn new() -> InstanceStateNetworkCounters
InstanceStateNetworkCounters represents packet counters as part of the network section of an instance’s state.