pub struct InstancesPost {Show 14 fields
pub architecture: Option<String>,
pub config: Option<Value>,
pub description: Option<String>,
pub devices: Option<Value>,
pub disk_only: Option<bool>,
pub ephemeral: Option<bool>,
pub instance_type: Option<String>,
pub name: Option<String>,
pub profiles: Option<Vec<String>>,
pub restore: Option<String>,
pub source: Option<Box<InstanceSource>>,
pub start: Option<bool>,
pub stateful: Option<bool>,
pub type: Option<String>,
}Fields
architecture: Option<String>Architecture name
config: Option<Value>Instance configuration (see doc/instances.md)
description: Option<String>Instance description
devices: Option<Value>Instance devices (see doc/instances.md)
disk_only: Option<bool>Whether only the instances disk should be restored
ephemeral: Option<bool>Whether the instance is ephemeral (deleted on shutdown)
instance_type: Option<String>Cloud instance type (AWS, GCP, Azure, …) to emulate with limits
name: Option<String>Instance name
profiles: Option<Vec<String>>List of profiles applied to the instance
restore: Option<String>If set, instance will be restored to the provided snapshot name
source: Option<Box<InstanceSource>>start: Option<bool>Whether to start the instance after creation
stateful: Option<bool>Whether the instance currently has saved state on disk
type: Option<String>Implementations
Sourceimpl InstancesPost
impl InstancesPost
pub fn new() -> InstancesPost