pub struct ServerEnvironment {Show 24 fields
pub addresses: Option<Vec<String>>,
pub architectures: Option<Vec<String>>,
pub certificate: Option<String>,
pub certificate_fingerprint: Option<String>,
pub driver: Option<String>,
pub driver_version: Option<String>,
pub firewall: Option<String>,
pub kernel: Option<String>,
pub kernel_architecture: Option<String>,
pub kernel_features: Option<HashMap<String, String>>,
pub kernel_version: Option<String>,
pub lxc_features: Option<HashMap<String, String>>,
pub os_name: Option<String>,
pub os_version: Option<String>,
pub project: Option<String>,
pub server: Option<String>,
pub server_clustered: Option<bool>,
pub server_event_mode: Option<String>,
pub server_name: Option<String>,
pub server_pid: Option<i64>,
pub server_version: Option<String>,
pub storage: Option<String>,
pub storage_supported_drivers: Option<Vec<ServerStorageDriverInfo>>,
pub storage_version: Option<String>,
}Fields
addresses: Option<Vec<String>>List of addresses the server is listening on
architectures: Option<Vec<String>>List of architectures supported by the server
certificate: Option<String>Server certificate as PEM encoded X509
certificate_fingerprint: Option<String>Server certificate fingerprint as SHA256
driver: Option<String>List of supported instance drivers (separate by " | ")
driver_version: Option<String>List of supported instance driver versions (separate by " | ")
firewall: Option<String>Current firewall driver
kernel: Option<String>OS kernel name
kernel_architecture: Option<String>OS kernel architecture
kernel_features: Option<HashMap<String, String>>Map of kernel features that were tested on startup
kernel_version: Option<String>Kernel version
lxc_features: Option<HashMap<String, String>>Map of LXC features that were tested on startup
os_name: Option<String>Name of the operating system (Linux distribution)
os_version: Option<String>Version of the operating system (Linux distribution)
project: Option<String>Current project name
server: Option<String>Server implementation name
server_clustered: Option<bool>Whether the server is part of a cluster
server_event_mode: Option<String>Mode that the event distribution subsystem is operating in on this server. Either "full-mesh", "hub-server" or "hub-client".
server_name: Option<String>Server hostname
server_pid: Option<i64>PID of the daemon
server_version: Option<String>Server version
storage: Option<String>List of active storage drivers (separate by " | ")
storage_supported_drivers: Option<Vec<ServerStorageDriverInfo>>List of supported storage drivers
storage_version: Option<String>List of active storage driver versions (separate by " | ")
Implementations
Sourceimpl ServerEnvironment
impl ServerEnvironment
pub fn new() -> ServerEnvironment