pub struct ServerUntrusted {
pub api_extensions: Option<Vec<String>>,
pub api_status: Option<String>,
pub api_version: Option<String>,
pub auth: Option<String>,
pub auth_methods: Option<Vec<String>>,
pub config: Option<Value>,
pub public: Option<bool>,
}Expand description
ServerUntrusted : ServerUntrusted represents a server configuration for an untrusted client
Fields
api_extensions: Option<Vec<String>>List of supported API extensions
api_status: Option<String>Support status of the current API (one of "devel", "stable" or "deprecated")
api_version: Option<String>API version number
auth: Option<String>Whether the client is trusted (one of "trusted" or "untrusted")
auth_methods: Option<Vec<String>>List of supported authentication methods
config: Option<Value>Server configuration map (refer to doc/server.md)
public: Option<bool>Whether the server is public-only (only public endpoints are implemented)
Implementations
Sourceimpl ServerUntrusted
impl ServerUntrusted
Sourcepub fn new() -> ServerUntrusted
pub fn new() -> ServerUntrusted
ServerUntrusted represents a server configuration for an untrusted client