pub struct StorageVolumeBitmapsPost {
pub disabled: Option<bool>,
pub granularity: Option<i64>,
pub name: Option<String>,
pub persistent: Option<bool>,
}Expand description
StorageVolumeBitmapsPost : StorageVolumeBitmapsPost represents the fields available for a new volume bitmap
Fields
disabled: Option<bool>The bitmap is created in the disabled state
granularity: Option<i64>Granularity of the dirty bitmap in bytes
name: Option<String>Bitmap name
persistent: Option<bool>true if the bitmap was stored on disk, is scheduled to be stored on disk, or both
Implementations
Sourceimpl StorageVolumeBitmapsPost
impl StorageVolumeBitmapsPost
Sourcepub fn new() -> StorageVolumeBitmapsPost
pub fn new() -> StorageVolumeBitmapsPost
StorageVolumeBitmapsPost represents the fields available for a new volume bitmap