pub async fn instance_exec_post(
configuration: &Configuration,
name: &str,
project: Option<&str>,
exec: Option<InstanceExecPost>,
) -> Result<InstancesPut202Response, Error<InstanceExecPostError>>Expand description
Executes a command inside an instance. The returned operation metadata will contain either 2 or 4 websockets. In non-interactive mode, you’ll get one websocket for each of stdin, stdout and stderr. In interactive mode, a single bi-directional websocket is used for stdin and stdout/stderr. An additional "control" socket is always added on top which can be used for out of band communications. This allows sending signals and window sizing information through.